@@ -1,161 +1,155 @@
-#define DTKWIDGET_CLASS_DWidgetUtil
-#define DTKWIDGET_CLASS_DDesktopServices
-#define DTKWIDGET_CLASS_DFileIconProvider
-#define DTKWIDGET_CLASS_DHiDPIHelper
-#define DTKWIDGET_CLASS_DPasswdEditAnimated
-#define DTKWIDGET_CLASS_DTitlebar
-#define DTKWIDGET_CLASS_DMainWindow
+// it is auto make config
 #define DTKWIDGET_CLASS_DAboutDialog
-#define DTKWIDGET_CLASS_DApplication
-#define DTKWIDGET_CLASS_DBlurEffectWidget
-#define DTKWIDGET_CLASS_DClipEffectWidget
-#define DTKWIDGET_CLASS_DGraphicsDropShadowEffect
-#define DTKWIDGET_CLASS_DPlatformWindowHandle
-#define DTKWIDGET_CLASS_DGraphicsClipEffect
-#define DTKWIDGET_CLASS_DExpandGroup
-#define DTKWIDGET_CLASS_DArrowButton
-#define DTKWIDGET_CLASS_DArrowLineExpand
-#define DTKWIDGET_CLASS_DThemeManager
-#define DTKWIDGET_CLASS_DWaterProgress
-#define DTKWIDGET_CLASS_DSimpleListView
-#define DTKWIDGET_CLASS_DSimpleListItem
-#define DTKWIDGET_CLASS_DSearchEdit
-#define DTKWIDGET_CLASS_DPageIndicator
-#define DTKWIDGET_CLASS_DSettingsWidgetFactory
-#define DTKWIDGET_CLASS_DSettingsDialog
-#define DTKWIDGET_CLASS_DSpinner
-#define DTKWIDGET_CLASS_DCrumbEdit
-#define DTKWIDGET_CLASS_DTabBar
-#define DTKWIDGET_CLASS_DSuggestButton
-#define DTKWIDGET_CLASS_DStyleOption
-#define DTKWIDGET_CLASS_DToast
-#define DTKWIDGET_CLASS_DFileDialog
-#define DTKWIDGET_CLASS_DLineEdit
-#define DTKWIDGET_CLASS_DIpv4LineEdit
-#define DTKWIDGET_CLASS_DStyleOptionLineEdit
+#define DTKWIDGET_CLASS_DAbstractDialog
+#define DTKWIDGET_CLASS_DAccessibilityChecker
+#define DTKWIDGET_CLASS_DAccessibleWidget
+#define DTKWIDGET_CLASS_DAlertControl
 #define DTKWIDGET_CLASS_DAnchors
-#define DTKWIDGET_CLASS_DSegmentedControl
-#define DTKWIDGET_CLASS_DSegmentedHighlight
+#define DTKWIDGET_CLASS_DApplication
+#define DTKWIDGET_CLASS_DApplicationHelper
+#define DTKWIDGET_CLASS_DApplicationSettings
+#define DTKWIDGET_CLASS_DArrowButton
+#define DTKWIDGET_CLASS_DArrowLineDrawer
+#define DTKWIDGET_CLASS_DArrowLineExpand
+#define DTKWIDGET_CLASS_DArrowRectangle
 #define DTKWIDGET_CLASS_DBackgroundGroup
-#define DTKWIDGET_CLASS_DStyleOptionBackgroundGroup
-#define DTKWIDGET_CLASS_DStyleOptionButton
-#define DTKWIDGET_CLASS_DPalette
-#define DTKWIDGET_CLASS_DFontSizeManager
-#define DTKWIDGET_CLASS_DStyle
-#define DTKWIDGET_CLASS_DFloatingButton
-#define DTKWIDGET_CLASS_DListView
-#define DTKWIDGET_CLASS_DStyleOptionViewItem
-#define DTKWIDGET_CLASS_DScrollBar
-#define DTKWIDGET_CLASS_DPushButton
-#define DTKWIDGET_CLASS_DToolButton
-#define DTKWIDGET_CLASS_DRadioButton
-#define DTKWIDGET_CLASS_DCheckButton
-#define DTKWIDGET_CLASS_DCommandLinkButton
-#define DTKWIDGET_CLASS_DDialogButtonBox
-#define DTKWIDGET_CLASS_DListWidget
-#define DTKWIDGET_CLASS_DTreeWidget
-#define DTKWIDGET_CLASS_DTableWidget
-#define DTKWIDGET_CLASS_DGroupBox
-#define DTKWIDGET_CLASS_DScrollArea
-#define DTKWIDGET_CLASS_DToolBox
-#define DTKWIDGET_CLASS_DTableWidget
-#define DTKWIDGET_CLASS_DStackedWidget
-#define DTKWIDGET_CLASS_DFrame
-#define DTKWIDGET_CLASS_DWidget
-#define DTKWIDGET_CLASS_DMDIArea
-#define DTKWIDGET_CLASS_DDockWidget
+#define DTKWIDGET_CLASS_DBlurEffectWidget
+#define DTKWIDGET_CLASS_DButtonBox
+#define DTKWIDGET_CLASS_DCalendarWidget
+#define DTKWIDGET_CLASS_DCheckBox
+#define DTKWIDGET_CLASS_DClipEffectWidget
+#define DTKWIDGET_CLASS_DColorDialog
+#define DTKWIDGET_CLASS_DColoredProgressBar
+#define DTKWIDGET_CLASS_DColumnView
 #define DTKWIDGET_CLASS_DComboBox
-#define DTKWIDGET_CLASS_DFontComboBox
-#define DTKWIDGET_CLASS_DLineEdit
-#define DTKWIDGET_CLASS_DTextEdit
-#define DTKWIDGET_CLASS_DPlainTextEdit
-#define DTKWIDGET_CLASS_DSpinBox
-#define DTKWIDGET_CLASS_DDoubleSpinBox
-#define DTKWIDGET_CLASS_DTimeEdit
+#define DTKWIDGET_CLASS_DCommandLinkButton
+#define DTKWIDGET_CLASS_DCrumbEdit
+#define DTKWIDGET_CLASS_DDataWidgetMapper
 #define DTKWIDGET_CLASS_DDateEdit
 #define DTKWIDGET_CLASS_DDateTimeEdit
+#define DTKWIDGET_CLASS_DDesktopServices
 #define DTKWIDGET_CLASS_DDial
-#define DTKWIDGET_CLASS_DHorizontalScrollBar
-#define DTKWIDGET_CLASS_DVerticalScrollBar
-#define DTKWIDGET_CLASS_DHorizontalSlider
-#define DTKWIDGET_CLASS_DVerticalSlider
-#define DTKWIDGET_CLASS_DKeySequenceEdit
-#define DTKWIDGET_CLASS_DLabel
-#define DTKWIDGET_CLASS_DTextBrowser
-#define DTKWIDGET_CLASS_DGraphicsView
-#define DTKWIDGET_CLASS_DCalendarWidget
-#define DTKWIDGET_CLASS_DLCDNumber
-#define DTKWIDGET_CLASS_DProgressBar
-#define DTKWIDGET_CLASS_DHorizontalLine
-#define DTKWIDGET_CLASS_DVerticalLine
-#define DTKWIDGET_CLASS_DOpenGLWidget
-#define DTKWIDGET_CLASS_DQuickWidget
-#define DTKWIDGET_CLASS_DWebView
-#define DTKWIDGET_CLASS_DAccessibleWidget
-#define DTKWIDGET_CLASS_DCheckBox
-#define DTKWIDGET_CLASS_DColorDialog
-#define DTKWIDGET_CLASS_DColumnView
-#define DTKWIDGET_CLASS_DDataWidgetMapper
+#define DTKWIDGET_CLASS_DDialog
+#define DTKWIDGET_CLASS_DDialogButtonBox
+#define DTKWIDGET_CLASS_DDialogCloseButton
+#define DTKWIDGET_CLASS_DDockWidget
+#define DTKWIDGET_CLASS_DDoubleSpinBox
+#define DTKWIDGET_CLASS_DDrawer
+#define DTKWIDGET_CLASS_DDrawerGroup
+#define DTKWIDGET_CLASS_DErrorMessage
+#define DTKWIDGET_CLASS_DExpandGroup
+#define DTKWIDGET_CLASS_DFileChooserEdit
+#define DTKWIDGET_CLASS_DFileDialog
+#define DTKWIDGET_CLASS_DFileIconProvider
+#define DTKWIDGET_CLASS_DFloatingButton
+#define DTKWIDGET_CLASS_DFloatingMessage
+#define DTKWIDGET_CLASS_DFloatingWidget
 #define DTKWIDGET_CLASS_DFocusFrame
+#define DTKWIDGET_CLASS_DFontComboBox
+#define DTKWIDGET_CLASS_DFontDialog
+#define DTKWIDGET_CLASS_DFontSizeManager
+#define DTKWIDGET_CLASS_DFrame
+#define DTKWIDGET_CLASS_DGraphicsClipEffect
+#define DTKWIDGET_CLASS_DGraphicsDropShadowEffect
+#define DTKWIDGET_CLASS_DGraphicsView
+#define DTKWIDGET_CLASS_DGroupBox
 #define DTKWIDGET_CLASS_DHeaderView
+#define DTKWIDGET_CLASS_DHiDPIHelper
+#define DTKWIDGET_CLASS_DHorizontalLine
+#define DTKWIDGET_CLASS_DHorizontalSlider
+#define DTKWIDGET_CLASS_DIconButton
+#define DTKWIDGET_CLASS_DImageButton
 #define DTKWIDGET_CLASS_DInputDialog
+#define DTKWIDGET_CLASS_DIpv4LineEdit
+#define DTKWIDGET_CLASS_DKeySequenceEdit
+#define DTKWIDGET_CLASS_DLCDNumber
+#define DTKWIDGET_CLASS_DLabel
+#define DTKWIDGET_CLASS_DLineEdit
+#define DTKWIDGET_CLASS_DListView
+#define DTKWIDGET_CLASS_DListWidget
+#define DTKWIDGET_CLASS_DMDIArea
+#define DTKWIDGET_CLASS_DMainWindow
 #define DTKWIDGET_CLASS_DMdiArea
 #define DTKWIDGET_CLASS_DMdiSubWindow
-#define DTKWIDGET_CLASS_DErrorMessage
-#define DTKWIDGET_CLASS_DFontDialog
 #define DTKWIDGET_CLASS_DMenu
 #define DTKWIDGET_CLASS_DMenuBar
 #define DTKWIDGET_CLASS_DMessageBox
+#define DTKWIDGET_CLASS_DMessageManager
+#define DTKWIDGET_CLASS_DOpenGLWidget
+#define DTKWIDGET_CLASS_DPageIndicator
+#define DTKWIDGET_CLASS_DPaletteHelper
+#define DTKWIDGET_CLASS_DPasswordEdit
+#define DTKWIDGET_CLASS_DPlainTextEdit
+#define DTKWIDGET_CLASS_DPlatformWindowHandle
+#define DTKWIDGET_CLASS_DPrintPreviewDialog
+#define DTKWIDGET_CLASS_DProgressBar
+#define DTKWIDGET_CLASS_DPushButton
+#define DTKWIDGET_CLASS_DQuickWidget
+#define DTKWIDGET_CLASS_DRadioButton
 #define DTKWIDGET_CLASS_DRubberBand
+#define DTKWIDGET_CLASS_DScrollArea
+#define DTKWIDGET_CLASS_DScrollBar
+#define DTKWIDGET_CLASS_DSearchComboBox
+#define DTKWIDGET_CLASS_DSearchEdit
+#define DTKWIDGET_CLASS_DSegmentedControl
+#define DTKWIDGET_CLASS_DSegmentedHighlight
+#define DTKWIDGET_CLASS_DSettingsDialog
+#define DTKWIDGET_CLASS_DSettingsWidgetFactory
+#define DTKWIDGET_CLASS_DShadowLine
+#define DTKWIDGET_CLASS_DSimpleListItem
+#define DTKWIDGET_CLASS_DSimpleListView
 #define DTKWIDGET_CLASS_DSlider
+#define DTKWIDGET_CLASS_DSpinBox
+#define DTKWIDGET_CLASS_DSpinner
 #define DTKWIDGET_CLASS_DSplitter
-#define DTKWIDGET_CLASS_DStatusBar
-#define DTKWIDGET_CLASS_DTabWidget
-#define DTKWIDGET_CLASS_DTableView
-#define DTKWIDGET_CLASS_DTileRules
-#define DTKWIDGET_CLASS_DToolBar
-#define DTKWIDGET_CLASS_DToolTip
-#define DTKWIDGET_CLASS_DTreeView
-#define DTKWIDGET_CLASS_DUndoView
-#define DTKWIDGET_CLASS_DWhatsThis
-#define DTKWIDGET_CLASS_DWizard
-#define DTKWIDGET_CLASS_DWizardPage
-#define DTKWIDGET_CLASS_DDialog
-#define DTKWIDGET_CLASS_DStyledItemDelegate
+#define DTKWIDGET_CLASS_DStackedWidget
 #define DTKWIDGET_CLASS_DStandardItem
-#define DTKWIDGET_CLASS_DIconButton
-#define DTKWIDGET_CLASS_DFloatingWidget
+#define DTKWIDGET_CLASS_DStatusBar
+#define DTKWIDGET_CLASS_DStyle
 #define DTKWIDGET_CLASS_DStyleHelper
+#define DTKWIDGET_CLASS_DStyleOption
+#define DTKWIDGET_CLASS_DStyleOptionBackgroundGroup
+#define DTKWIDGET_CLASS_DStyleOptionButton
+#define DTKWIDGET_CLASS_DStyleOptionLineEdit
+#define DTKWIDGET_CLASS_DStyleOptionViewItem
 #define DTKWIDGET_CLASS_DStylePainter
 #define DTKWIDGET_CLASS_DStyledIconEngine
-#define DTKWIDGET_CLASS_DArrowRectangle
-#define DTKWIDGET_CLASS_DImageButton
+#define DTKWIDGET_CLASS_DStyledItemDelegate
+#define DTKWIDGET_CLASS_DSuggestButton
 #define DTKWIDGET_CLASS_DSwitchButton
+#define DTKWIDGET_CLASS_DTabBar
+#define DTKWIDGET_CLASS_DTabWidget
+#define DTKWIDGET_CLASS_DTableView
+#define DTKWIDGET_CLASS_DTableWidget
+#define DTKWIDGET_CLASS_DTabletWindowOptionButton
+#define DTKWIDGET_CLASS_DTextBrowser
+#define DTKWIDGET_CLASS_DTextEdit
+#define DTKWIDGET_CLASS_DThemeManager
+#define DTKWIDGET_CLASS_DTileRules
+#define DTKWIDGET_CLASS_DTimeEdit
+#define DTKWIDGET_CLASS_DTipLabel
+#define DTKWIDGET_CLASS_DTitlebar
+#define DTKWIDGET_CLASS_DToast
+#define DTKWIDGET_CLASS_DToolBar
+#define DTKWIDGET_CLASS_DToolBox
+#define DTKWIDGET_CLASS_DToolButton
+#define DTKWIDGET_CLASS_DToolTip
+#define DTKWIDGET_CLASS_DTreeView
+#define DTKWIDGET_CLASS_DTreeWidget
+#define DTKWIDGET_CLASS_DUndoView
+#define DTKWIDGET_CLASS_DVerticalLine
+#define DTKWIDGET_CLASS_DVerticalSlider
+#define DTKWIDGET_CLASS_DWarningButton
+#define DTKWIDGET_CLASS_DWaterProgress
+#define DTKWIDGET_CLASS_DWebView
+#define DTKWIDGET_CLASS_DWhatsThis
+#define DTKWIDGET_CLASS_DWidget
+#define DTKWIDGET_CLASS_DWidgetUtil
 #define DTKWIDGET_CLASS_DWindowCloseButton
 #define DTKWIDGET_CLASS_DWindowMaxButton
 #define DTKWIDGET_CLASS_DWindowMinButton
 #define DTKWIDGET_CLASS_DWindowOptionButton
-#define DTKWIDGET_CLASS_DTabletWindowOptionButton
 #define DTKWIDGET_CLASS_DWindowQuitFullButton
-#define DTKWIDGET_CLASS_DApplicationHelper
-#define DTKWIDGET_CLASS_DFloatingWidget
-#define DTKWIDGET_CLASS_DFloatingMessage
-#define DTKWIDGET_CLASS_DMessageManager
-#define DTKWIDGET_CLASS_DButtonBox
-#define DTKWIDGET_CLASS_DApplicationSettings
-#define DTKWIDGET_CLASS_DWarningButton
-#define DTKWIDGET_CLASS_DDialogCloseButton
-#define DTKWIDGET_CLASS_DPasswordEdit
-#define DTKWIDGET_CLASS_DTipLabel
-#define DTKWIDGET_CLASS_DShadowLine
-#define DTKWIDGET_CLASS_DColoredProgressBar
-#define DTKWIDGET_CLASS_DAbstractdialog
-#define DTKWIDGET_CLASS_DLabel
-#define DTKWIDGET_CLASS_DDrawer
-#define DTKWIDGET_CLASS_DDrawerGroup
-#define DTKWIDGET_CLASS_DArrowLineDrawer
-#define DTKWIDGET_CLASS_DAlertControl
-#define DTKWIDGET_CLASS_DSearchComboBox
-#define DTKWIDGET_CLASS_DPrintPreviewDialog
-#define DTKWIDGET_CLASS_DFileChooserEdit
-#define DTKWIDGET_CLASS_DPaletteHelper
+#define DTKWIDGET_CLASS_DWizard
+#define DTKWIDGET_CLASS_DWizardPage
+#define DTKWIDGET_CLASS_DtkWidgets
